@@ -114,7 +114,7 @@ def get_trainer(params):
     callbacks = [  
                     LossOptimizerHandler(),
                     SchedulerStep(apply_on_phase=Phase.BATCH_END, apply_on_states=State.TRAIN),
-                    EarlyStopping(callback_monitor=CallbackMonitor(patience=3, monitor_type=MonitorType.LOSS, stats_type=StatsType.VAL, monitor_mode=MonitorMode.MIN)),
+                    EarlyStopping(callback_monitor=CallbackMonitor(monitor_type=MonitorType.LOSS, stats_type=StatsType.VAL, patience=3, monitor_mode=MonitorMode.MIN)),
                     StatsPrint(round_values_on_print_to=7)
                 ]
 
