@@ -18,7 +18,7 @@ def get_parameters():
     data_loader_steps = 100
     return N, D_in, H, D_out, num_epochs, data_loader, data_loader_steps
 
-def get_trainer(N, D_in, H, D_out, num_epochs, data_loader, data_loader_steps):
+def get_trainer(N, D_in, H, D_out, data_loader, data_loader_steps):
 
     device = tu.get_gpu_device_if_available()
 
@@ -55,7 +55,6 @@ def get_trainer(N, D_in, H, D_out, num_epochs, data_loader, data_loader_steps):
                       val_data_loader=data_loader,
                       train_steps=data_loader_steps,
                       val_steps=data_loader_steps,
-                      num_epochs=num_epochs,
                       callbacks=callbacks,
                       name='Scheduler-Step-On-Batch-Example')
     return trainer
@@ -65,11 +64,11 @@ def run():
 
     N, D_in, H, D_out, num_epochs, data_loader, data_loader_steps = get_parameters()
 
-    trainer = get_trainer(N, D_in, H, D_out, num_epochs, data_loader, data_loader_steps)
+    trainer = get_trainer(N, D_in, H, D_out, data_loader, data_loader_steps)
     
     trainer.summary()
 
     #WE NOW EXPECT SchedulerStep TO INVOKE StepLR AT THE END OF EVERY BATCH
-    trainer.train()
+    trainer.train(num_epochs)
 
     trainer.evaluate(data_loader, data_loader_steps)
\ No newline at end of file
