@@ -1,6 +1,8 @@
-from lpd.metrics.metric_base import MetricBase
+from lpd.metrics.metric_base import MetricBase, MetricConfusionMatrixBase
 from lpd.metrics.binary_accuracy import BinaryAccuracy
 from lpd.metrics.binary_accuracy_with_logits import BinaryAccuracyWithLogits
 from lpd.metrics.categorical_accuracy import CategoricalAccuracy
 from lpd.metrics.categorical_accuracy_with_logits import CategoricalAccuracyWithLogits
 from lpd.metrics.top_k_categorical_accuracy import TopKCategoricalAccuracy
+from lpd.metrics.tp_tn_fp_fn import TruePositives, FalsePositives, TrueNegatives, FalseNegatives
+
