@@ -3,7 +3,7 @@ from tqdm import tqdm
 from lpd.metrics import MetricBase
 from lpd.callbacks import CallbackContext, CollectOutputs, LossOptimizerHandlerBase
 from lpd.enums import State, Phase
-from lpd.trainer_stats import TrainerStats
+from lpd.trainer_stats import TrainerStats, StatsResult
 import lpd.utils.file_utils as fu
 from lpd.extensions.custom_schedulers import DoNothingToLR
 
@@ -33,7 +33,6 @@ class Trainer():
             load_trainer - for creating a new Trainer instance from a saved Trainer checkpoint
             summary - will print information about the trainer and the model
             stop - will indicate this trainer to stop, e.g. from a callback
-            get_last_outputs - the last outputs fed to the model as numpy array
             train - this is the training loop, it will invoke the training and validation phases, as well as callbacks and maintain stats
             evaluate - will run a forward pass on the test data
             predict_sample - make prediction on single sample
@@ -84,6 +83,7 @@ class Trainer():
 
         self._stopped = False
         self._last_outputs = None
+        self._last_labels = None
         self._total_num_epochs = 0
 
     def _validate_metric_name_to_func(self):
@@ -137,26 +137,24 @@ class Trainer():
 
     def _tqdm_description(self, loop, stats):
         desc = self._get_epoch_description()
-
         loop.set_description(desc)
         if self.state != State.PREDICT:
-            metrics = stats.get_metrics()
-            if metrics:
-                loop.set_postfix(loss=stats.get_loss(), metrics=metrics)
+            stats_result = StatsResult('', stats)
+            if stats_result.metrics:
+                loop.set_postfix(loss=stats_result.loss, metrics=stats_result.metrics)
             else:
-                loop.set_postfix(loss=stats.get_loss())
+                loop.set_postfix(loss=stats_result.loss)
             
     def _print_verbos_2(self, stats, verbose):
         if verbose != 2:
             return
         desc = self._get_epoch_description()
-        loss=stats.get_loss()
-        metrics=stats.get_metrics()
-        if metrics:
-            metrics_str = f', metrics={metrics}'
+        stats_result = StatsResult('', stats)
+        if stats_result.metrics:
+            metrics_str = f', metrics={stats_result.metrics}'
         else:
             metrics_str = ''
-        print(f'{desc}, loss={loss}{metrics_str}')
+        print(f'{desc}, loss={stats_result.loss}{stats_result.metrics_str}')
 
     def _prepare_next_batch(self, batch):
         if self.state == State.PREDICT:
@@ -182,6 +180,7 @@ class Trainer():
             batch_size = len(y)
             outputs = self.model(*x)
             self._last_outputs = outputs
+            self._last_labels = y
             loss = loss_f(outputs, y)
             stats.add_loss(loss, batch_size)
             stats.add_metrics(outputs, y, batch_size)
@@ -397,9 +396,6 @@ class Trainer():
     def stop(self):
         self._stopped = True
 
-    def get_last_outputs(self):
-        return self._last_outputs.data.numpy()
-
     def train(self, num_epochs, verbose=1):
         """
             num_epochs - amount of epochs to run
@@ -436,7 +432,7 @@ class Trainer():
 
     def evaluate(self, test_data_loader, test_steps, verbose=1):
         """
-            verbose: 0 = no progress bar, 1 = progress bar, 2 = one line per epoch
+            verbose: 0 = no progress bar, 1 = progress bar
         """
         self._stopped = False
         self.phase = Phase.TEST_BEGIN
@@ -448,6 +444,8 @@ class Trainer():
         self._invoke_callbacks()
         self.phase = Phase.IDLE
 
+        return StatsResult(self.name, self.test_stats)
+
     def predict_sample(self, inputs):
         # MAKE BATCH WITH 1 SAMPLE USING unsqueeze
         outputs = self.predict_batch(inputs.unsqueeze(0))
